@@ -75,6 +75,45 @@ def ssh_copy_keys(hostname, username=None):
     distro.conn.exit()
 
 
+def validate_host_ip(ips, subnets):
+    """
+    Make sure that a given host all subnets specified will have at least one IP
+    in that range.
+    """
+    # Make sure we prune ``None`` arguments
+    subnets = [s for s in subnets if s is not None]
+    validate_one_subnet = len(subnets) == 1
+
+    def ip_in_one_subnet(ips, subnet):
+        """ ensure an ip exists in at least one subnet """
+        for ip in ips:
+            if net.ip_in_subnet(ip, subnet):
+                return True
+        return False
+
+    for subnet in subnets:
+        if ip_in_one_subnet(ips, subnet):
+            if validate_one_subnet:
+                return
+            else:  # keep going to make sure the other subnets are ok
+                continue
+        else:
+            msg = "subnet (%s) is not valid for any of the ips found %s" % (subnet, str(ips))
+            raise RuntimeError(msg)
+
+
+def get_public_network_ip(ips, public_subnet):
+    """
+    Given a public subnet, chose the one IP from the remote host that exists
+    within the subnet range.
+    """
+    for ip in ips:
+        if net.ip_in_subnet(ip, public_subnet):
+            return ip
+    msg = "IPs (%s) are not valid for any of subnet specified %s" % (str(ips), str(public_subnet))
+    raise RuntimeError(msg)
+
+
 def new(args):
     if args.ceph_conf:
         raise RuntimeError('will not create a ceph conf file if attemtping to re-use with `--ceph-conf` flag')
@@ -85,12 +124,38 @@ def new(args):
     fsid = args.fsid or uuid.uuid4()
     cfg.set('global', 'fsid', str(fsid))
 
+    # if networks were passed in, lets set them in the
+    # global section
+    if args.public_network:
+        cfg.set('global', 'public network', str(args.public_network))
+
+    if args.cluster_network:
+        cfg.set('global', 'cluster network', str(args.cluster_network))
+
     mon_initial_members = []
     mon_host = []
 
     for (name, host) in mon_hosts(args.mon):
+        # Try to ensure we can ssh in properly before anything else
+        if args.ssh_copykey:
+            ssh_copy_keys(host, args.username)
+
+        # Now get the non-local IPs from the remote node
+        distro = hosts.get(host, username=args.username)
+        remote_ips = net.ip_addresses(distro.conn)
+        distro.conn.exit()
+
+        # Validate subnets if we received any
+        if args.public_network or args.cluster_network:
+            validate_host_ip(remote_ips, [args.public_network, args.cluster_network])
+
+        # Pick the IP that matches the public cluster (if we were told to do
+        # so) otherwise pick the first, non-local IP
         LOG.debug('Resolving host %s', host)
-        ip = net.get_nonlocal_ip(host)
+        if args.public_network:
+            ip = get_public_network_ip(remote_ips, args.public_network)
+        else:
+            ip = net.get_nonlocal_ip(host)
         LOG.debug('Monitor %s at %s', name, ip)
         mon_initial_members.append(name)
         try:
@@ -101,8 +166,7 @@ def new(args):
         except socket.error:
             mon_host.append(ip)
 
-        if args.ssh_copykey:
-            ssh_copy_keys(host, args.username)
+
 
     LOG.debug('Monitor initial members are %s', mon_initial_members)
     LOG.debug('Monitor addrs are %s', mon_host)
@@ -184,6 +248,18 @@ def make(parser):
         help='provide an alternate FSID for ceph.conf generation',
     )
 
+    parser.add_argument(
+        '--cluster-network',
+        help='specify the (internal) cluster network',
+        type=arg_validators.Subnet(),
+    )
+
+    parser.add_argument(
+        '--public-network',
+        help='specify the public network for a cluster',
+        type=arg_validators.Subnet(),
+    )
+
     parser.set_defaults(
         func=new,
         )
